package com.ruoyi.buyerapi.mapper;

import java.util.List;
import com.ruoyi.buyerapi.domain.BuyerDesignRecord;

/**
 * 装备调试设计记录Mapper接口
 * 
 * @author ruoyi
 * @date 2022-09-22
 */
public interface BuyerDesignRecordMapper 
{
    /**
     * 查询装备调试设计记录
     * 
     * @param id 装备调试设计记录主键
     * @return 装备调试设计记录
     */
    public BuyerDesignRecord selectBuyerDesignRecordById(String id);

    /**
     * 查询装备调试设计记录列表
     * 
     * @param buyerDesignRecord 装备调试设计记录
     * @return 装备调试设计记录集合
     */
    public List<BuyerDesignRecord> selectBuyerDesignRecordList(BuyerDesignRecord buyerDesignRecord);

    /**
     * 统计装备调试设计记录列表
     *
     * @param buyerDesignRecord 装备调试设计记录
     * @return 装备调试设计记录集合
     */
    public List<BuyerDesignRecord> selectStatistBuyerDesignRecordList(BuyerDesignRecord buyerDesignRecord);

    /**
     * 新增装备调试设计记录
     * 
     * @param buyerDesignRecord 装备调试设计记录
     * @return 结果
     */
    public int insertBuyerDesignRecord(BuyerDesignRecord buyerDesignRecord);

    /**
     * 修改装备调试设计记录
     * 
     * @param buyerDesignRecord 装备调试设计记录
     * @return 结果
     */
    public int updateBuyerDesignRecord(BuyerDesignRecord buyerDesignRecord);

    /**
     * 删除装备调试设计记录
     * 
     * @param id 装备调试设计记录主键
     * @return 结果
     */
    public int deleteBuyerDesignRecordById(String id);

    /**
     * 批量删除装备调试设计记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBuyerDesignRecordByIds(String[] ids);
}
