package com.ruoyi.web.controller.buyerapi;

import java.util.List;
import cn.hutool.core.util.IdUtil;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.buyerapi.domain.BuyerDesignRecord;
import com.ruoyi.buyerapi.service.IBuyerDesignRecordService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 装备调试设计记录Controller
 * 
 * @author ruoyi
 * @date 2022-09-22
 */
@Api(tags = "装备调试设计记录")
@RestController
@RequestMapping("/buyer/designrecord")
public class BuyerDesignRecordController extends BaseController
{
    @Autowired
    private IBuyerDesignRecordService buyerDesignRecordService;

    /**
     * 查询装备调试设计记录列表
     */
    @ApiOperation(value = "查询装备调试设计记录列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "collectDate", value = "领用日期", required = true, paramType = "query"),
            @ApiImplicitParam(name = "projectName", value = "项目名称", required = true, paramType = "query"),
            @ApiImplicitParam(name = "info", value = "摘要", required = true, paramType = "query"),
            @ApiImplicitParam(name = "type", value = "种类", required = true, paramType = "query"),
            @ApiImplicitParam(name = "createBy", value = "操作人", required = true, paramType = "query")
    })
    @PreAuthorize("@ss.hasPermi('buyer:designrecord:list')")
    @GetMapping("/list")
    public TableDataInfo list(BuyerDesignRecord buyerDesignRecord)
    {
        startPage();
        List<BuyerDesignRecord> list = buyerDesignRecordService.selectBuyerDesignRecordList(buyerDesignRecord);
        return getDataTable(list);
    }

    /**
     * 统计装备调试设计记录列表
     */
    @ApiOperation(value = "统计装备调试设计记录列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "projectName", value = "项目名称", required = true, paramType = "query")
    })
    @GetMapping("/statist")
    public TableDataInfo statist(BuyerDesignRecord buyerDesignRecord)
    {
        startPage();
        List<BuyerDesignRecord> list = buyerDesignRecordService.selectStatistBuyerDesignRecordList(buyerDesignRecord);
        return getDataTable(list);
    }

    /**
     * 导出装备调试设计记录列表
     */
    @ApiOperation(value = "导出装备调试设计记录列表")
    @PreAuthorize("@ss.hasPermi('buyer:designrecord:export')")
    @Log(title = "装备调试设计记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BuyerDesignRecord buyerDesignRecord)
    {
        List<BuyerDesignRecord> list = buyerDesignRecordService.selectBuyerDesignRecordList(buyerDesignRecord);
        ExcelUtil<BuyerDesignRecord> util = new ExcelUtil<BuyerDesignRecord>(BuyerDesignRecord.class);
        util.exportExcel(response, list, "装备调试设计记录数据");
    }

    /**
     * 获取装备调试设计记录详细信息
     */
    @ApiOperation(value = "获取装备调试设计记录详细信息")
    @PreAuthorize("@ss.hasPermi('buyer:designrecord:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return AjaxResult.success(buyerDesignRecordService.selectBuyerDesignRecordById(id));
    }

    /**
     * 新增装备调试设计记录
     */
    @ApiOperation(value = "新增装备调试设计记录")
    @PreAuthorize("@ss.hasPermi('buyer:designrecord:add')")
    @Log(title = "装备调试设计记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BuyerDesignRecord buyerDesignRecord)
    {
        buyerDesignRecord.setId(IdUtil.simpleUUID());
        buyerDesignRecord.setCreateBy(getUsername());
        return toAjax(buyerDesignRecordService.insertBuyerDesignRecord(buyerDesignRecord));
    }

    /**
     * 修改装备调试设计记录
     */
    @ApiOperation(value = "修改装备调试设计记录")
    @PreAuthorize("@ss.hasPermi('buyer:designrecord:edit')")
    @Log(title = "装备调试设计记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BuyerDesignRecord buyerDesignRecord)
    {
        buyerDesignRecord.setUpdateBy(getUsername());
        return toAjax(buyerDesignRecordService.updateBuyerDesignRecord(buyerDesignRecord));
    }

    /**
     * 删除装备调试设计记录
     */
    @ApiOperation(value = "删除装备调试设计记录")
    @PreAuthorize("@ss.hasPermi('buyer:designrecord:remove')")
    @Log(title = "装备调试设计记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(buyerDesignRecordService.deleteBuyerDesignRecordByIds(ids));
    }
}
